==> claromentis-framework-8.13.65-b8aa1bfb.zip: console/src/Output/MultiplexedOutput.php <==
<?php
namespace Claromentis\Console\Output;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array("_e41dd20" . "8b3f8688" . "e037c1f5" . "7903a2af" . "3" => base64_decode("T3V0cHV0I" . "GludGVyZm" . "FjZSAn"), "_2b879ee7476ab710ec475" . "ba39e3fe902" => base64_decode("aXNfY" . "Q=="), "_b2c18fea2fd27be5faced70" . "fc93730a8" => base64_decode("JyBkb2VzIG5vdCBpbXBsZW1" . "lbnQg"), "_db6f0ba0791e9a635407659a9fe04e4" . "0" => base64_decode("aXNfb2JqZWN" . "0"), "_fc9d7314a9d9958d" . "8fa0a403ba8ff197" => base64_decode("Z2V0X2NsY" . "XNz"));
use Symfony\Component\Console\Formatter\OutputFormatter;
use Symfony\Component\Console\Formatter\OutputFormatterInterface;
use Symfony\Component\Console\Output\OutputInterface;




class MultiplexedOutput implements OutputInterface
{
    
    
    
    
    protected $verbosity = self::VERBOSITY_NORMAL;
    
    
    
    
    protected $formatter = null;
    
    
    
    
    protected $interfaces = [];
    
    
    
    
    
    
    
    
    
    public function __construct(array $_3afbfd6216bfbb1e35b97511f18c8397, $_e84eb3b6c91429c62da5eddaef93bb19 = self::VERBOSITY_NORMAL, $_4de82f87bac18df795ec4161918650aa = null, OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3 = null)
    {
        $this->verbosity = $_e84eb3b6c91429c62da5eddaef93bb19;
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        if ($this->formatter === null) {
            $this->formatter = new OutputFormatter($_4de82f87bac18df795ec4161918650aa);
        }
        foreach ($_3afbfd6216bfbb1e35b97511f18c8397 as $_5b08afc6598666e83143bd42ce733d9c) {
            if (!$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_db6f0ba0791e9a" . "635407659a9fe04" . "e40"]($_5b08afc6598666e83143bd42ce733d9c)) {
                continue;
            }
            if (!$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_2b879ee7476ab710ec475ba39" . "e3fe902"]($_5b08afc6598666e83143bd42ce733d9c, OutputInterface::class)) {
                $_6b33cbff9a72786d9d5e3d7fc9322a40 = $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_fc9d7314a9d9958d" . "8fa0a403ba8ff197"]($_5b08afc6598666e83143bd42ce733d9c);
                throw new \InvalidArgumentException($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_e41dd208b3f8" . "688e037c1f579" . "03a2af3"] . $_6b33cbff9a72786d9d5e3d7fc9322a40 . $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_b2c18fea2fd27be" . "5faced70fc93730a" . "8"] . OutputInterface::class);
            }
            $this->interfaces[] = $_5b08afc6598666e83143bd42ce733d9c;
        }
    }
    
    
    
    
    
    
    public function getInterfaces()
    {
        return $this->interfaces;
    }
    
    
    
    
    
    
    
    
    public function write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea = false, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    
    public function writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    public function setVerbosity($_8571ac32155d45081f21fab1bc366aff)
    {
        $this->verbosity = $_8571ac32155d45081f21fab1bc366aff;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setVerbosity($_8571ac32155d45081f21fab1bc366aff);
        }
    }
    
    
    
    
    
    
    public function getVerbosity()
    {
        return $this->verbosity;
    }
    
    
    
    
    
    
    public function isQuiet()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_QUIET;
    }
    
    
    
    
    
    
    public function isVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERBOSE;
    }
    
    
    
    
    
    
    public function isVeryVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERY_VERBOSE;
    }
    
    
    
    
    
    
    public function isDebug()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_DEBUG;
    }
    
    
    
    
    
    
    public function setDecorated($_4de82f87bac18df795ec4161918650aa)
    {
        $this->formatter->setDecorated($_4de82f87bac18df795ec4161918650aa);
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->getFormatter()->setDecorated($_4de82f87bac18df795ec4161918650aa);
        }
    }
    
    
    
    
    
    
    public function isDecorated()
    {
        return $this->formatter->isDecorated();
    }
    
    
    
    
    
    
    public function setFormatter(OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3)
    {
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        }
    }
    
    
    
    
    
    
    public function getFormatter()
    {
        return $this->formatter;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: console/src/Output/MultiplexedOutput.php <==
<?php
namespace Claromentis\Console\Output;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_b2c18fea2fd27b" . "e5faced70fc9373" . "0a8" => base64_decode("JyBkb2VzIG5vdCBpbXBsZW1lbnQ" . "g"), "_fc9d7314a9d9958d8" . "fa0a403ba8ff197" => base64_decode("Z2V0X2NsYX" . "Nz"), "_db6f0ba0791e9a63" . "5407659a9fe04e40" => base64_decode("aXNfb" . "2JqZW" . "N0"), "_2b879ee7476ab" . "710ec475ba39e3" . "fe902" => base64_decode("aXNfYQ=" . "="), "_e41dd208b3f8688" . "e037c1f57903a2af" . "3" => base64_decode("T3V0cHV0IGludG" . "VyZmFjZSAn"));
use Symfony\Component\Console\Formatter\OutputFormatter;
use Symfony\Component\Console\Formatter\OutputFormatterInterface;
use Symfony\Component\Console\Output\OutputInterface;




class MultiplexedOutput implements OutputInterface
{
    
    
    
    
    protected $verbosity = self::VERBOSITY_NORMAL;
    
    
    
    
    protected $formatter = null;
    
    
    
    
    protected $interfaces = [];
    
    
    
    
    
    
    
    
    
    public function __construct(array $_3afbfd6216bfbb1e35b97511f18c8397, $_e84eb3b6c91429c62da5eddaef93bb19 = self::VERBOSITY_NORMAL, $_4de82f87bac18df795ec4161918650aa = null, OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3 = null)
    {
        $this->verbosity = $_e84eb3b6c91429c62da5eddaef93bb19;
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        if ($this->formatter === null) {
            $this->formatter = new OutputFormatter($_4de82f87bac18df795ec4161918650aa);
        }
        foreach ($_3afbfd6216bfbb1e35b97511f18c8397 as $_5b08afc6598666e83143bd42ce733d9c) {
            if (!$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_db6f0ba0791" . "e9a635407659" . "a9fe04e40"]($_5b08afc6598666e83143bd42ce733d9c)) {
                continue;
            }
            if (!$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_2b879ee7476ab710e" . "c475ba39e3fe902"]($_5b08afc6598666e83143bd42ce733d9c, OutputInterface::class)) {
                $_6b33cbff9a72786d9d5e3d7fc9322a40 = $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_fc9d7314a9d9958d8fa0a403" . "ba8ff197"]($_5b08afc6598666e83143bd42ce733d9c);
                throw new \InvalidArgumentException($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_e41dd208b3f8688e037c1f57903a2af" . "3"] . $_6b33cbff9a72786d9d5e3d7fc9322a40 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_b2c18fea2" . "fd27be5fac" . "ed70fc9373" . "0a8"] . OutputInterface::class);
            }
            $this->interfaces[] = $_5b08afc6598666e83143bd42ce733d9c;
        }
    }
    
    
    
    
    
    
    public function getInterfaces()
    {
        return $this->interfaces;
    }
    
    
    
    
    
    
    
    
    public function write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea = false, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    
    public function writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    public function setVerbosity($_8571ac32155d45081f21fab1bc366aff)
    {
        $this->verbosity = $_8571ac32155d45081f21fab1bc366aff;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setVerbosity($_8571ac32155d45081f21fab1bc366aff);
        }
    }
    
    
    
    
    
    
    public function getVerbosity()
    {
        return $this->verbosity;
    }
    
    
    
    
    
    
    public function isQuiet()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_QUIET;
    }
    
    
    
    
    
    
    public function isVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERBOSE;
    }
    
    
    
    
    
    
    public function isVeryVerbose()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_VERY_VERBOSE;
    }
    
    
    
    
    
    
    public function isDebug()
    {
        return $this->verbosity === OutputInterface::VERBOSITY_DEBUG;
    }
    
    
    
    
    
    
    public function setDecorated($_4de82f87bac18df795ec4161918650aa)
    {
        $this->formatter->setDecorated($_4de82f87bac18df795ec4161918650aa);
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->getFormatter()->setDecorated($_4de82f87bac18df795ec4161918650aa);
        }
    }
    
    
    
    
    
    
    public function isDecorated()
    {
        return $this->formatter->isDecorated();
    }
    
    
    
    
    
    
    public function setFormatter(OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3)
    {
        $this->formatter = $_a83a2289b24ef3674668e88bc61b3ab3;
        foreach ($this->interfaces as $_5b08afc6598666e83143bd42ce733d9c) {
            $_5b08afc6598666e83143bd42ce733d9c->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        }
    }
    
    
    
    
    
    
    public function getFormatter()
    {
        return $this->formatter;
    }
}
